Name:           veusz
Version:        4.1
Release:        %mkrel 1
Summary:        GUI scientific plotting package

Group:          Sciences/Mathematics
# The entire source code is GPLv2+ except helpers/src/_nc_cntr.c which is Python
License:        GPLv2+ and Python
URL:            https://veusz.github.io/
Source0:        https://github.com/veusz/veusz/releases/download/veusz-%{version}/veusz-%{version}.tar.gz
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-qt6-devel
BuildRequires:  python3-sip6
BuildRequires:  python3-pyqt6-sip
BuildRequires:  python3-tomli

Requires:       python3dist(astropy) >= 0.2.3

%{?_python3_sip_api:Requires: sip-api(%{_python3_sip_api_major}) >= %{_python3_sip_api}}
Requires:       python3dist(numpy)
Requires:       python3dist(h5py)
Requires:       python3-qt6-core
Requires:       python3-qt6-gui
Requires:       python3-qt6-printsupport
Requires:       python3-qt6-svg
Requires:       python3-qt6-widgets
Requires:       python3-pkg-resources
Requires:       /usr/bin/env
Provides:       python3-veusz = %{version}

# we don't want to provide private python extension libs
%{?filter_setup:
%filter_provides_in %{python3_sitearch}/veusz/helpers/.*\.so$
%filter_setup
}

%description
Veusz is a 2D and 3D scientific plotting package, designed to create
publication-ready vector PDF and SVG output. It features GUI,
command-line, and scripting interfaces. Graphs are constructed from
widgets, allowing complex layouts to be designed. Veusz supports
plotting functions, data with error bars, keys, labels, stacked plots,
ternary plots, vector plots, contours, images, shapes and fitting
data. 3D point, surface, volume and function plots are also supported.

%prep
%autosetup -p1 -n veusz-%{version}

find -name \*~ | xargs rm -f

# remove shebangs from scripts which aren't installed
# (veusz allows these to be executed if app isn't installed properly)
sed -i '/^#!/d' veusz/veusz_main.py
sed -i '/^#!/d' veusz/veusz_listen.py

%build
%py3_build

%install
# veusz-resource-dir: put data files in location given

%py3_install -- --veusz-resource-dir=%{buildroot}%{_datadir}/veusz --disable-install-examples

# tell veusz where its resource directory is in _datadir
ln -s %{_datadir}/veusz \
    %{buildroot}%{python3_sitearch}/veusz/resources

# tell it where to look for examples and COPYING
ln -s  %{_defaultdocdir}/%{name}/examples \
    %{buildroot}%{_datadir}/veusz

# install desktop file
desktop-file-install  \
    --dir %{buildroot}%{_datadir}/applications \
    support/veusz.desktop

# file to register .vsz mimetype
mkdir -p %{buildroot}%{_datadir}/mime/packages/
install -p support/veusz.xml -m 0644 %{buildroot}%{_datadir}/mime/packages/

# appdata file
mkdir -p %{buildroot}%{_metainfodir}/
install -p support/veusz.appdata.xml -m 0644 %{buildroot}%{_metainfodir}/

# also link in hicolor icons
for size in 16 32 48 64 128; do
    odir=%{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps
    mkdir -p $odir
    ln -s %{_datadir}/veusz/icons/veusz_${size}.png ${odir}/veusz.png
done
odir=%{buildroot}%{_datadir}/icons/hicolor/scalable/apps
mkdir -p $odir
ln -s %{_datadir}/veusz/icons/veusz.svg $odir

# install man pages
mkdir -p %{buildroot}%{_mandir}/man1
install -p Documents/man-page/veusz.1 -m 0644 \
    %{buildroot}%{_mandir}/man1

%check
%define enable_tests 0
%if %{enable_tests}
# as the data directory hasn't got the same absolute path we have
# to define VEUSZ_RESOURCE_DIR
PYTHONPATH=%{buildroot}%{python3_sitearch} \
    VEUSZ_RESOURCE_DIR=%{buildroot}%{_datadir}/veusz \
    QT_QPA_PLATFORM=minimal \
    %{python3} tests/runselftest.py
%endif

%files
%doc README.md AUTHORS
%doc examples
%doc Documents/manual/html
%license COPYING
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/applications/*
%{_datadir}/mime/packages/*
%{_metainfodir}/*.xml
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/veusz/
%{python3_sitearch}/veusz-*.egg-info
%{python3_sitearch}/veusz


%changelog
* Sat Jun 14 2025 daviddavid <daviddavid> 4.1-1.mga10
+ Revision: 2191344
- new version: 4.1

* Thu Jun 05 2025 daviddavid <daviddavid> 4.0-1.mga10
+ Revision: 2188208
- new version: 4.0

* Sun May 25 2025 daviddavid <daviddavid> 3.99.0-1.mga10
+ Revision: 2186388
- new version: 3.99.0
- switch to PyQt6

* Wed Mar 05 2025 daviddavid <daviddavid> 3.6.2-4.mga10
+ Revision: 2160947
- rebuild for python 3.13

* Tue Dec 24 2024 daviddavid <daviddavid> 3.6.2-3.mga10
+ Revision: 2129848
- rebuild for numpy 2

* Tue Dec 19 2023 papoteur <papoteur> 3.6.2-2.mga10
+ Revision: 2019507
- Mass Rebuild - Python 3.12

* Tue Oct 31 2023 daviddavid <daviddavid> 3.6.2-1.mga10
+ Revision: 2003010
- new version: 3.6.2

* Wed Dec 28 2022 daviddavid <daviddavid> 3.5.3-1.mga9
+ Revision: 1927305
- new version: 3.5.3

* Sun Sep 25 2022 neoclust <neoclust> 3.4-5.mga9
+ Revision: 1892300
- New version 3.4
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tv <tv> 3.3.1-4.mga9
+ Revision: 1778505
- Rebuild for python-3.10

* Sat Mar 20 2021 daviddavid <daviddavid> 3.3.1-3.mga9
+ Revision: 1705399
- rebuild for python 3.9

* Thu Dec 17 2020 umeabot <umeabot> 3.3.1-2.mga8
+ Revision: 1660131
- Rebuild for new Qt5

* Sun Dec 06 2020 daviddavid <daviddavid> 3.3.1-1.mga8
+ Revision: 1653815
- new version: 3.3.1

* Wed Dec 02 2020 daviddavid <daviddavid> 3.3-1.mga8
+ Revision: 1651754
- new version: 3.3

* Wed Jul 22 2020 ovitters <ovitters> 3.2.1-3.mga8
+ Revision: 1608031
- rebuild for get rid of pythonegg requires

* Sat Jun 27 2020 joequant <joequant> 3.2.1-2.mga8
+ Revision: 1599605
- rebuild with new python

* Tue Mar 24 2020 daviddavid <daviddavid> 3.2.1-1.mga8
+ Revision: 1559181
- new version: 3.2.1

* Mon Mar 09 2020 daviddavid <daviddavid> 3.2-1.mga8
+ Revision: 1555006
- new version: 3.2

* Mon Feb 17 2020 umeabot <umeabot> 3.1-2.mga8
+ Revision: 1537253
- Mageia 8 Mass Rebuild

* Sun Oct 27 2019 daviddavid <daviddavid> 3.1-1.mga8
+ Revision: 1456034
- new version: 3.1

* Sun Sep 15 2019 tv <tv> 3.0.1-5.mga8
+ Revision: 1441621
- rebuild for python-3.8

* Tue Apr 02 2019 umeabot <umeabot> 3.0.1-4.mga7
+ Revision: 1385247
- Qt5 Rebuild

* Tue Jan 08 2019 daviddavid <daviddavid> 3.0.1-3.mga7
+ Revision: 1352819
- rebuild for new Python 3.7

* Sun Sep 23 2018 umeabot <umeabot> 3.0.1-2.mga7
+ Revision: 1301609
- Mageia 7 Mass Rebuild

* Sun Jul 22 2018 daviddavid <daviddavid> 3.0.1-1.mga7
+ Revision: 1244837
- new version: 3.0.1
- remove xvfb dependency on build

* Tue Jun 12 2018 daviddavid <daviddavid> 3.0-1.mga7
+ Revision: 1236464
- new version: 3.0
- port to PyQt5 and Python3

* Tue Aug 08 2017 daviddavid <daviddavid> 1.26.1-2.mga7
+ Revision: 1138844
- rebuild for new sip 4.19

* Mon May 29 2017 eatdirt <eatdirt> 1.26.1-1.mga6
+ Revision: 1105495
- Update to version 1.26.1

* Sun Dec 04 2016 daviddavid <daviddavid> 1.24-8.mga6
+ Revision: 1072095
- disable testsuite as xvfb-run fails again
- fix some dangling symlinks thus fixing desktop file icon not displayed in menu application
- use upstream desktop file and upstream mimetype file
- package the upstream appdata file
- use more new python macros

* Mon Jun 27 2016 akien <akien> 1.24-5.mga6
+ Revision: 1037871
- Rebuild again for updated PyQt4
- Rebuild in core/release

* Sat Jun 25 2016 akien <akien> 1.24-3.mga6
+ Revision: 1037524
- Rebuild for python-sip 4.18

* Sun May 22 2016 joequant <joequant> 1.24-2.mga6
+ Revision: 1017526
- bump
- upgrade to 1.24

* Tue Feb 09 2016 umeabot <umeabot> 1.18-12.mga6
+ Revision: 951854
- Mageia 6 Mass Rebuild

* Sat Nov 22 2014 alexl <alexl> 1.18-10.mga5
+ Revision: 798338
- translated desktop file (merged with OpenSuse and Debian)
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.18-8.mga5
+ Revision: 730702
- rebuild for missing pythoneggs deps

* Fri Sep 26 2014 tv <tv> 1.18-7.mga5
+ Revision: 725276
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 1.18-6.mga5
+ Revision: 690199
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Wed Mar 19 2014 fwang <fwang> 1.18-4.mga5
+ Revision: 605485
- rebuild for new sip

* Tue Oct 22 2013 umeabot <umeabot> 1.18-3.mga4
+ Revision: 544609
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.18-2.mga4
+ Revision: 499970
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 04 2013 joequant <joequant> 1.18-1.mga4
+ Revision: 463103
- update to 1.18

* Tue Jun 18 2013 joequant <joequant> 1.17.1-1.mga4
+ Revision: 444683
- fix typo
- imported package veusz

